#include <ESP8266.h>
#include <I2CLiquidCrystal.h>
#include <Wire.h>

#define SSID        "SSID-NAME"
#define PASSWORD    "PASSWORD"
#define SERVER_PORT (9999)
#define I2C_ADDR    0x3c
#define BRIGHT      127
#define lcd_row     16
#define lcd_col     2

I2CLiquidCrystal oled( I2C_ADDR, (uint8_t)BRIGHT );

SoftwareSerial mySerial( 3, 2 ); 
ESP8266 wifi( mySerial );

char message[lcd_col][lcd_row + 1];

void setup(void)
{
    oled.begin( lcd_row , lcd_col );
    oled.display();
    oled.clear();
    oled.noBlink();
    oled.noCursor();

    int i=0;
    while ( i < lcd_col ){
        strcpy(message[i], "");
        i = i + 1;
    }
    
    Serial.begin(9600);
    
    mySerial.begin(115200);
    mySerial.println("AT+UART_CUR=9600,8,1,0,0");
    delay(10);
    mySerial.begin(9600); 
    delay(10);
        
    if ( wifi.setOprToStation() ) {
        Serial.println( "OK:Setup" );
    } else {
        Serial.println( "Error:Setup" );
    }

    if ( wifi.joinAP( SSID, PASSWORD ) ) {
        Serial.println( wifi.getLocalIP().c_str() );
    } else {
        Serial.println( "Failed : AP Connect" );
    }

    delay(10);
    
    if ( wifi.enableMUX() ) {
        Serial.println("OK: Multiple");
    } else {
        Serial.println("ERROR: Multiple");
    }

     if (wifi.startTCPServer( SERVER_PORT ) ) {
        Serial.println("OK: Server");
    } else {
        Serial.println("ERROR: Server");
    }
    
    if ( wifi.setTCPServerTimeout( 10 ) ) { 
        Serial.println("OK: Set timeout");
    } else {
        Serial.println("ERROR: Set timeout");
    }   
    
    Serial.println("Server stand-by.");
    
    delay(100);
}

void loop(void)
{
    char buf[128] = {0};
    char lcd_buf[lcd_row + 1];
    uint8_t mux_id;
    int len, i;

    len = wifi.recv( &mux_id, buf, sizeof(buf), 100 );
    if (len > 0) {
        Serial.println("Connected.");
        
        for( i = 0; i < len; i++ ) {
            Serial.print( (char)buf[ i ] );
            if ( i < lcd_row ){
                    lcd_buf[i] = (char)buf[i];
            }
        }
        Serial.println("");
        
        while( i < lcd_row ){
            lcd_buf[ i ] = ' ';
            i = i + 1;
        }

        i = 0;
        while ( i < lcd_col - 1 ){
            strcpy( message[ i ], message[ i + 1 ] );
            i = i + 1;
        }
        strcpy( message[ lcd_col - 1 ], lcd_buf );

        oled.clear();
        i = 0;
        while ( i < lcd_col ){
            oled.setCursor( 0, i );
            oled.print( message[ i ] );
            i = i + 1;
        }
                
        if ( wifi.releaseTCP( mux_id ) ) {
            Serial.println( "OK: Release Connect." );
        }      
    }
}
