#include <SPI.h>
#include <ESP8266.h>
 
#define SS_PIN      9
#define INTERVAL    60000
#define SSID        "SSID"
#define PASSWORD    "PASSWORD"
#define HOST_NAME   "HOST_NAME"
#define HOST_PORT   (80)
#define POST_PAGE   "arduino_temp.php"

SoftwareSerial mySerial( 3, 2 ); 
ESP8266 wifi( mySerial );

void setup(void) {
    Serial.begin( 9600 );
    
    pinMode( SS_PIN, OUTPUT);
    
    SPI.setBitOrder( MSBFIRST );
    SPI.setClockDivider( SPI_CLOCK_DIV128 );
    SPI.setDataMode( SPI_MODE0 );
 
    SPI.begin();
  
    digitalWrite( SS_PIN, LOW );
    SPI.transfer(0xFF);
    digitalWrite( SS_PIN, HIGH );
    delay(100);
    
    digitalWrite( SS_PIN, LOW );
    SPI.transfer(0x0C);
    SPI.transfer(0x80);
    digitalWrite( SS_PIN, HIGH );
    delay(100);
    
    digitalWrite( SS_PIN, LOW );
    SPI.transfer(0x54);
    digitalWrite( SS_PIN, HIGH );
    delay(1000);

    mySerial.begin(115200);
    mySerial.println("AT+UART_CUR=9600,8,1,0,0");
    delay(10);
    mySerial.begin(9600); 
    delay(10);
        
    if ( wifi.setOprToStation() ) {
        Serial.println( "OK:Setup" );
    } else {
        Serial.println( "Error:Setup" );
    }

    if ( wifi.joinAP( SSID, PASSWORD ) ) {
        Serial.println( wifi.getLocalIP().c_str() );
    } else {
        Serial.println( "Failed : AP Connect" );
    }
    delay(10);
    if ( wifi.disableMUX() ) {
        Serial.println("OK: Single");
    } else {
        Serial.println("ERROR: Single");
    }
    delay(1000);
}

void loop(void) {
    unsigned char data_h, data_l;
    int data;
    float temp_data;
    char request[100], temp_char[32];
    
    digitalWrite( SS_PIN, LOW );

    data_h = SPI.transfer(0); 
    data_l = SPI.transfer(0); 
  
    digitalWrite( SS_PIN, HIGH );

    data = data_h << 8 | data_l;
    temp_data = (float)data / 128.0;
    dtostrf( temp_data, 3, 2, temp_char); 

    Serial.print( temp_data );
    Serial.println( " C" );
    
    strcpy( request, "GET /" );
    strcat( request, POST_PAGE ); 
    strcat( request, "?mode=post&temp=" );
    strcat( request, temp_char );
    strcat( request, " HTTP/1.1\r\n" );
    strcat( request, "Host:" );
    strcat( request, HOST_NAME );
    strcat( request, "\r\n\r\n" );
    
    if ( wifi.createTCP( HOST_NAME, HOST_PORT ) ){
        Serial.println( "OK: TCP Connect.");
        wifi.send( request, strlen( request ) );
        wifi.releaseTCP();
    } else {
        Serial.println( "Failed: TCP Connect." );
    }

    delay( INTERVAL );
}
 

